@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -23,6 +21,7 @@
 #define __CUT_ASSERTIONS_H__
 
 #include <string.h>
+#include <errno.h>
 #include <cutter/cut-public.h>
 #include <cutter/cut-assertions-helper.h>
 
@@ -100,6 +99,24 @@ extern "C" {
 #define cut_notify(format, ...)                  \
     cut_test_register_result(NOTIFICATION, NULL, format, ## __VA_ARGS__)
 
+/**
+ * cut_omit:
+ * @format: the message format. See the printf() documentation.
+ * @...: the parameters to insert into the format string.
+ *
+ * Omit the test.
+ *
+ * e.g.:
+ * |[
+ * if (version < 2.0)
+ *   cut_omit("Require >= 2.0");
+ * ]|
+ *
+ * Since: 0.8
+ */
+#define cut_omit(format, ...)                           \
+    cut_test_fail(OMISSION, NULL, format, ## __VA_ARGS__)
+
 /**
  * cut_assert:
  * @expression: the expression to check.
@@ -249,9 +266,11 @@ extern "C" {
  */
 #define cut_assert_equal_double(expected, error, actual, ...) do        \
 {                                                                       \
-    double _expected = (expected);                                      \
-    double _actual = (actual);                                          \
-    double _error = (error);                                            \
+    double _expected, _error, _actual;                                  \
+                                                                        \
+    _expected = (expected);                                             \
+    _error = (error);                                                   \
+    _actual = (actual);                                                 \
     if (_expected - _error <= _actual &&                                \
         _actual <= _expected + _error) {                                \
         cut_test_pass();                                                \
@@ -295,13 +314,23 @@ extern "C" {
         if (_actual && strcmp(_expected, _actual) == 0) {               \
             cut_test_pass();                                            \
         } else {                                                        \
-            cut_test_fail(FAILURE,                                      \
-                          cut_take_printf("<%s == %s>\n"                \
-                                          "expected: <%s>\n"            \
-                                          " but was: <%s>",             \
-                                          #expected, #actual,           \
-                                          _expected, _actual),          \
-                          ## __VA_ARGS__);                              \
+            const char *message;                                        \
+                                                                        \
+            message = cut_take_printf("<%s == %s>\n"                    \
+                                      "expected: <%s>\n"                \
+                                      " but was: <%s>",                 \
+                                      #expected, #actual,               \
+                                      _expected, _actual);              \
+            if (_expected && _actual) {                                 \
+                const char *diff;                                       \
+                                                                        \
+                diff = cut_take_diff(_expected, _actual);               \
+                message = cut_take_printf("%s\n"                        \
+                                          "diff:\n"                     \
+                                          "%s",                         \
+                                          message, diff);               \
+            }                                                           \
+            cut_test_fail(FAILURE, message, ## __VA_ARGS__);            \
         }                                                               \
     }                                                                   \
 } while(0)
@@ -388,8 +417,8 @@ extern "C" {
  */
 #define cut_assert_equal_string_array(expected, actual, ...) do         \
 {                                                                       \
-    const char **_expected = (const char **)(expected);                 \
-    const char **_actual = (const char **)(actual);                     \
+    char **_expected = (expected);                                      \
+    char **_actual = (actual);                                          \
     if (_expected && _actual &&                                         \
         cut_utils_compare_string_array(_expected, _actual)) {           \
         cut_test_pass();                                                \
@@ -417,7 +446,7 @@ extern "C" {
  *
  * e.g.:
  * |[
- * cut_assert_operator(1, <, 2) -> (1 < 2)
+ * cut_assert_operator(1, <, 2) -> (1 < 2);
  * ]|
  */
 #define cut_assert_operator(lhs, operator, rhs, ...) do                 \
@@ -444,7 +473,7 @@ extern "C" {
  *
  * e.g.:
  * |[
- * cut_assert_operator_int(1, <, 2) -> (1 < 2)
+ * cut_assert_operator_int(1, <, 2) -> (1 < 2);
  * ]|
  */
 #define cut_assert_operator_int(lhs, operator, rhs, ...) do             \
@@ -475,7 +504,7 @@ extern "C" {
  *
  * e.g.:
  * |[
- * cut_assert_equal(!strcmp, "abc", "abc") -> Pass
+ * cut_assert_equal(!strcmp, "abc", "abc"); -> Pass
  * ]|
  */
 #define cut_assert_equal(function, expected, actual, ...) do            \
@@ -490,6 +519,36 @@ extern "C" {
     }                                                                   \
 } while(0)
 
+/**
+ * cut_assert_errno:
+ * @...: the parameters to insert into the format string.
+ * @...: optional format string, followed by parameters to insert
+ * into the format string (as with printf())
+ *
+ * Passes if errno is 0.
+ *
+ * e.g.:
+ * |[
+ * count = write(stdout, buffer, strlen(buffer));
+ * cut_assert_errno("Failed to write");            -> Pass when count != -1
+ * ]|
+ *
+ * Since: 0.8
+ */
+#define cut_assert_errno(...) do                                        \
+{                                                                       \
+    int _errno = errno;                                                 \
+    if (_errno == 0) {                                                  \
+        cut_test_pass();                                                \
+    } else {                                                            \
+        cut_test_fail(FAILURE,                                          \
+                      cut_take_printf("expected: <0> (errno)\n"         \
+                                      " but was: <%d> (%s)",            \
+                                      _errno, strerror(_errno)),        \
+                      ## __VA_ARGS__);                                  \
+    }                                                                   \
+} while(0)
+
 #ifdef __cplusplus
 }
 #endif
