@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -70,15 +68,6 @@ _cut_report_module_dir (void)
     return REPORT_MODULEDIR;
 }
 
-void
-cut_report_load (const gchar *base_dir)
-{
-    if (!base_dir)
-        base_dir = _cut_report_module_dir();
-
-    modules = g_list_concat(cut_module_load_modules(base_dir), modules);
-}
-
 static CutModule *
 cut_report_load_module (const gchar *name)
 {
@@ -99,47 +88,20 @@ cut_report_load_module (const gchar *name)
     return module;
 }
 
-void
-cut_report_unload (void)
-{
-    g_list_foreach(modules, (GFunc)cut_module_unload, NULL);
-    g_list_free(modules);
-    modules = NULL;
-}
-
-GList *
-cut_report_get_registered_types (void)
-{
-    return cut_module_collect_registered_types(modules);
-}
-
-GList *
-cut_report_get_log_domains (void)
-{
-    return cut_module_collect_log_domains(modules);
-}
-
-#define cut_report_init init
-G_DEFINE_ABSTRACT_TYPE (CutReport, cut_report, CUT_TYPE_LISTENER)
-#undef cut_report_init
+G_DEFINE_ABSTRACT_TYPE (CutReport, cut_report, G_TYPE_OBJECT)
 
 static void
 cut_report_class_init (CutReportClass *klass)
 {
     GObjectClass *gobject_class;
-    CutListenerClass *listener_class;
     GParamSpec *spec;
 
     gobject_class = G_OBJECT_CLASS(klass);
-    listener_class = CUT_LISTENER_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    listener_class->attach_to_runner   = NULL;
-    listener_class->detach_from_runner = NULL;
-
     spec = g_param_spec_string("filename",
                                "Filename",
                                "The name of output file",
@@ -151,7 +113,7 @@ cut_report_class_init (CutReportClass *klass)
 }
 
 static void
-init (CutReport *report)
+cut_report_init (CutReport *report)
 {
     CutReportPrivate *priv = CUT_REPORT_GET_PRIVATE(report);
 
@@ -167,6 +129,8 @@ dispose (GObject *object)
         g_free(priv->filename);
         priv->filename = NULL;
     }
+
+    G_OBJECT_CLASS(cut_report_parent_class)->dispose(object);
 }
 
 static void
@@ -232,27 +196,6 @@ cut_report_get_filename (CutReport *report)
     return CUT_REPORT_GET_PRIVATE(report)->filename;
 }
 
-gboolean
-cut_report_result_to_file (CutReport *report,
-                           const gchar *filename,
-                           CutReportFileMode mode)
-{
-    CutReportClass *klass;
-
-    g_return_val_if_fail(CUT_IS_REPORT(report), FALSE);
-    g_return_val_if_fail(filename, FALSE);
-
-    if (g_file_test(filename, G_FILE_TEST_EXISTS) &&
-        mode != CUT_REPORT_FILE_OVERWRITE)
-        return FALSE;
-
-    klass = CUT_REPORT_GET_CLASS(report);
-    if (klass->result_to_file)
-        return klass->result_to_file(report, filename, mode);
-    else
-        return FALSE;
-}
-
 #define GET_RESULTS(name)                               \
 gchar *                                                 \
 cut_report_get_ ## name ## _results (CutReport *report) \
