@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -41,11 +39,11 @@ typedef struct _CutTestCasePrivate	CutTestCasePrivate;
 struct _CutTestCasePrivate
 {
     CutSetupFunction setup;
-    CutTearDownFunction teardown;
+    CutTeardownFunction teardown;
     CutGetCurrentTestContextFunction get_current_test_context;
     CutSetCurrentTestContextFunction set_current_test_context;
-    CutInitializeFunction initialize;
-    CutFinalizeFunction finalize;
+    CutStartupFunction startup;
+    CutShutdownFunction shutdown;
 };
 
 enum
@@ -55,8 +53,8 @@ enum
     PROP_TEAR_DOWN_FUNCTION,
     PROP_GET_CURRENT_TEST_CONTEXT_FUNCTION,
     PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION,
-    PROP_INITIALIZE_FUNCTION,
-    PROP_FINALIZE_FUNCTION
+    PROP_STARTUP_FUNCTION,
+    PROP_SHUTDOWN_FUNCTION
 };
 
 enum
@@ -102,7 +100,7 @@ cut_test_case_class_init (CutTestCaseClass *klass)
     g_object_class_install_property(gobject_class, PROP_SETUP_FUNCTION, spec);
 
     spec = g_param_spec_pointer("tear-down-function",
-                                "TearDown Function",
+                                "Teardown Function",
                                 "The function for tear down",
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class, PROP_TEAR_DOWN_FUNCTION, spec);
@@ -123,20 +121,20 @@ cut_test_case_class_init (CutTestCaseClass *klass)
                                     PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION,
                                     spec);
 
-    spec = g_param_spec_pointer("initialize-function",
-                                "Initialize Function",
+    spec = g_param_spec_pointer("startup-function",
+                                "Startup Function",
                                 "The function for initialization of TestCase",
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class,
-                                    PROP_INITIALIZE_FUNCTION,
+                                    PROP_STARTUP_FUNCTION,
                                     spec);
 
-    spec = g_param_spec_pointer("finalize-function",
-                                "Finalize Function",
+    spec = g_param_spec_pointer("shutdown-function",
+                                "Shutdown Function",
                                 "The function for finalization of TestCase",
                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
     g_object_class_install_property(gobject_class,
-                                    PROP_FINALIZE_FUNCTION,
+                                    PROP_SHUTDOWN_FUNCTION,
                                     spec);
 
 
@@ -179,8 +177,8 @@ cut_test_case_init (CutTestCase *test_case)
     priv->teardown = NULL;
     priv->get_current_test_context = NULL;
     priv->set_current_test_context = NULL;
-    priv->initialize = NULL;
-    priv->finalize = NULL;
+    priv->startup = NULL;
+    priv->shutdown = NULL;
 }
 
 static void
@@ -210,11 +208,11 @@ set_property (GObject      *object,
       case PROP_SET_CURRENT_TEST_CONTEXT_FUNCTION:
         priv->set_current_test_context = g_value_get_pointer(value);
         break;
-      case PROP_INITIALIZE_FUNCTION:
-        priv->initialize = g_value_get_pointer(value);
+      case PROP_STARTUP_FUNCTION:
+        priv->startup = g_value_get_pointer(value);
         break;
-      case PROP_FINALIZE_FUNCTION:
-        priv->finalize = g_value_get_pointer(value);
+      case PROP_SHUTDOWN_FUNCTION:
+        priv->shutdown = g_value_get_pointer(value);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -237,11 +235,11 @@ get_property (GObject    *object,
       case PROP_TEAR_DOWN_FUNCTION:
         g_value_set_pointer(value, priv->teardown);
         break;
-      case PROP_INITIALIZE_FUNCTION:
-        g_value_set_pointer(value, priv->initialize);
+      case PROP_STARTUP_FUNCTION:
+        g_value_set_pointer(value, priv->startup);
         break;
-      case PROP_FINALIZE_FUNCTION:
-        g_value_set_pointer(value, priv->finalize);
+      case PROP_SHUTDOWN_FUNCTION:
+        g_value_set_pointer(value, priv->shutdown);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -252,11 +250,11 @@ get_property (GObject    *object,
 CutTestCase *
 cut_test_case_new (const gchar *name,
                    CutSetupFunction setup_function,
-                   CutTearDownFunction teardown_function,
+                   CutTeardownFunction teardown_function,
                    CutGetCurrentTestContextFunction get_current_test_context_function,
                    CutSetCurrentTestContextFunction set_current_test_context_function,
-                   CutInitializeFunction initialize_function,
-                   CutFinalizeFunction finalize_function)
+                   CutStartupFunction startup_function,
+                   CutShutdownFunction shutdown_function)
 {
     return g_object_new(CUT_TYPE_TEST_CASE,
                         "name", name,
@@ -266,13 +264,13 @@ cut_test_case_new (const gchar *name,
                         get_current_test_context_function,
                         "set-current-test-context-function",
                         set_current_test_context_function,
-                        "initialize-function", initialize_function,
-                        "finalize-function", finalize_function,
+                        "startup-function", startup_function,
+                        "shutdown-function", shutdown_function,
                         NULL);
 }
 
 static GList *
-get_filtered_tests (CutTestCase *test_case, const gchar **test_names)
+get_filtered_tests (CutTestCase *test_case, gchar **test_names)
 {
     CutTestContainer *container;
 
@@ -280,13 +278,12 @@ get_filtered_tests (CutTestCase *test_case, const gchar **test_names)
     if (test_names && *test_names) {
         return cut_test_container_filter_children(container, test_names);
     } else {
-        const gchar *default_test_names[] = {"/^test_/", NULL};
-        return cut_test_container_filter_children(container, default_test_names);
+        return g_list_copy(cut_test_container_get_children(container));
     }
 }
 
 guint
-cut_test_case_get_n_tests (CutTestCase *test_case, const gchar **test_names)
+cut_test_case_get_n_tests (CutTestCase *test_case,  gchar **test_names)
 {
     GList *filtered_tests;
     guint n_tests;
@@ -310,11 +307,14 @@ run (CutTestCase *test_case, CutTest *test, CutRunner *runner)
     CutTestCasePrivate *priv;
     CutTestContext *original_test_context, *test_context;
     gboolean success = TRUE;
+    gboolean is_multi_thread;
     jmp_buf jump_buffer;
 
     if (cut_runner_is_canceled(runner))
         return TRUE;
 
+    is_multi_thread = cut_runner_is_multi_thread(runner);
+
     priv = CUT_TEST_CASE_GET_PRIVATE(test_case);
     if (!priv->get_current_test_context ||
         !priv->set_current_test_context) {
@@ -323,6 +323,7 @@ run (CutTestCase *test_case, CutTest *test, CutRunner *runner)
     }
 
     test_context = cut_test_context_new(NULL, test_case, NULL);
+    cut_test_context_set_multi_thread(test_context, is_multi_thread);
     original_test_context = priv->get_current_test_context();
     priv->set_current_test_context(test_context);
 
@@ -375,14 +376,14 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
     CutTestResult *result;
     gboolean all_success = TRUE;
 
-    cut_runner_start_test_case(runner, test_case);
+    cut_runner_prepare_test_case(runner, test_case);
     g_signal_emit_by_name(test_case, "ready", g_list_length((GList *)tests));
     g_signal_emit_by_name(CUT_TEST(test_case), "start");
 
     priv = CUT_TEST_CASE_GET_PRIVATE(test_case);
 
-    if (priv->initialize) {
-        priv->initialize();
+    if (priv->startup) {
+        priv->startup();
     }
 
     for (list = tests; list; list = g_list_next(list)) {
@@ -403,6 +404,8 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
                              &status);
             g_signal_connect(test, "notification", G_CALLBACK(cb_test_status),
                              &status);
+            g_signal_connect(test, "omission", G_CALLBACK(cb_test_status),
+                             &status);
             if (!run(test_case, test, runner))
                 all_success = FALSE;
             g_signal_handlers_disconnect_by_func(test,
@@ -424,8 +427,8 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
                           NULL, result);
     g_object_unref(result);
 
-    if (priv->finalize) {
-        priv->finalize();
+    if (priv->shutdown) {
+        priv->shutdown();
     }
     g_signal_emit_by_name(CUT_TEST(test_case), "complete");
 
@@ -433,10 +436,9 @@ cut_test_case_run_tests (CutTestCase *test_case, CutRunner *runner,
 }
 
 gboolean
-cut_test_case_run_test (CutTestCase *test_case, CutRunner *runner,
-                        const gchar *name)
+cut_test_case_run_test (CutTestCase *test_case, CutRunner *runner, gchar *name)
 {
-    const gchar *test_names[] = {NULL, NULL};
+    gchar *test_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_CASE(test_case), FALSE);
 
@@ -447,7 +449,7 @@ cut_test_case_run_test (CutTestCase *test_case, CutRunner *runner,
 gboolean
 cut_test_case_run_with_filter (CutTestCase  *test_case,
                                CutRunner   *runner,
-                               const gchar **test_names)
+                               gchar **test_names)
 {
     GList *filtered_tests;
     gboolean success = TRUE;
@@ -463,7 +465,7 @@ cut_test_case_run_with_filter (CutTestCase  *test_case,
 gboolean
 cut_test_case_run (CutTestCase *test_case, CutRunner *runner)
 {
-    const gchar **test_names;
+    gchar **test_names;
 
     test_names = cut_runner_get_target_test_names(runner);
     return cut_test_case_run_with_filter(test_case, runner, test_names);
