@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -68,6 +66,12 @@ CutTest      *cut_test_context_get_test       (CutTestContext *context);
 void          cut_test_context_set_test       (CutTestContext *context,
                                                CutTest        *test);
 
+void          cut_test_context_set_multi_thread
+                                              (CutTestContext *context,
+                                               gboolean        use_multi_thread);
+gboolean      cut_test_context_is_multi_thread
+                                              (CutTestContext *context);
+
 void          cut_test_context_set_user_data  (CutTestContext *context,
                                                gpointer        user_data,
                                                GDestroyNotify  notify);
@@ -76,11 +80,13 @@ gboolean      cut_test_context_is_failed      (CutTestContext *context);
 
 void          cut_test_context_set_jump       (CutTestContext *context,
                                                jmp_buf        *buffer);
+void          cut_test_context_emit_signal    (CutTestContext *context,
+                                               CutTestResult  *result);
 
 G_END_DECLS
 
 #endif /* __CUT_TEST_CONTEXT_H__ */
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
