@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -43,18 +41,6 @@
 #include "cut-marshalers.h"
 #include "cut-test-result.h"
 
-#define CUT_TEST_SUITE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_SUITE, CutTestSuitePrivate))
-
-typedef struct _CutTestSuitePrivate	CutTestSuitePrivate;
-struct _CutTestSuitePrivate
-{
-};
-
-enum
-{
-    PROP_0
-};
-
 enum
 {
     READY_SIGNAL,
@@ -70,16 +56,6 @@ static gint cut_test_suite_signals[LAST_SIGNAL] = {0};
 
 G_DEFINE_TYPE (CutTestSuite, cut_test_suite, CUT_TYPE_TEST_CONTAINER)
 
-static void dispose        (GObject         *object);
-static void set_property   (GObject         *object,
-                            guint            prop_id,
-                            const GValue    *value,
-                            GParamSpec      *pspec);
-static void get_property   (GObject         *object,
-                            guint            prop_id,
-                            GValue          *value,
-                            GParamSpec      *pspec);
-
 static void
 cut_test_suite_class_init (CutTestSuiteClass *klass)
 {
@@ -87,10 +63,6 @@ cut_test_suite_class_init (CutTestSuiteClass *klass)
 
     gobject_class = G_OBJECT_CLASS(klass);
 
-    gobject_class->dispose      = dispose;
-    gobject_class->set_property = set_property;
-    gobject_class->get_property = get_property;
-
     cut_test_suite_signals[READY_SIGNAL]
         = g_signal_new("ready",
                        G_TYPE_FROM_CLASS(klass),
@@ -124,38 +96,6 @@ cut_test_suite_init (CutTestSuite *test_suite)
 {
 }
 
-static void
-dispose (GObject *object)
-{
-    G_OBJECT_CLASS(cut_test_suite_parent_class)->dispose(object);
-}
-
-static void
-set_property (GObject      *object,
-              guint         prop_id,
-              const GValue *value,
-              GParamSpec   *pspec)
-{
-    switch (prop_id) {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-        break;
-    }
-}
-
-static void
-get_property (GObject    *object,
-              guint       prop_id,
-              GValue     *value,
-              GParamSpec *pspec)
-{
-    switch (prop_id) {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-        break;
-    }
-}
-
 CutTestSuite *
 cut_test_suite_new (void)
 {
@@ -186,8 +126,7 @@ run (gpointer data)
     test_names = info->test_names;
 
     g_signal_emit_by_name(test_suite, "start-test-case", test_case);
-    success = cut_test_case_run_with_filter(test_case, runner,
-                                            (const gchar **)test_names);
+    success = cut_test_case_run_with_filter(test_case, runner, test_names);
     g_signal_emit_by_name(test_suite, "complete-test-case", test_case);
 
     g_object_unref(test_suite);
@@ -201,7 +140,7 @@ run (gpointer data)
 
 static void
 run_with_thread (CutTestSuite *test_suite, CutTestCase *test_case,
-                 CutRunner *runner, const gchar **test_names,
+                 CutRunner *runner, gchar **test_names,
                  gboolean try_thread, GList **threads, gboolean *success)
 {
     RunTestInfo *info;
@@ -303,7 +242,7 @@ i_will_be_back_handler (int signum)
 
 static void
 emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
-                   const gchar **test_names)
+                   gchar **test_names)
 {
     GList *node;
     guint n_test_cases, n_tests;
@@ -323,7 +262,7 @@ emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
 
 static gboolean
 cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
-                               GList *test_cases, const gchar **test_names)
+                               GList *test_cases, gchar **test_names)
 {
     GList *node, *threads = NULL;
     GList *sorted_test_cases;
@@ -339,7 +278,7 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
     signum = setjmp(jump_buffer);
     switch (signum) {
       case 0:
-        cut_runner_start_test_suite(runner, test_suite);
+        cut_runner_prepare_test_suite(runner, test_suite);
         emit_ready_signal(test_suite, sorted_test_cases, test_names);
         g_signal_emit_by_name(CUT_TEST(test_suite), "start");
 
@@ -397,8 +336,8 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
 gboolean
 cut_test_suite_run (CutTestSuite *suite, CutRunner *runner)
 {
-    const gchar **test_case_names;
-    const gchar **test_names;
+    gchar **test_case_names;
+    gchar **test_names;
 
     test_case_names = cut_runner_get_target_test_case_names(runner);
     test_names = cut_runner_get_target_test_names(runner);
@@ -408,9 +347,9 @@ cut_test_suite_run (CutTestSuite *suite, CutRunner *runner)
 
 gboolean
 cut_test_suite_run_test_case (CutTestSuite *suite, CutRunner *runner,
-                              const gchar *test_case_name)
+                              gchar *test_case_name)
 {
-    const gchar *test_case_names[] = {NULL, NULL};
+    gchar *test_case_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
 
@@ -421,10 +360,10 @@ cut_test_suite_run_test_case (CutTestSuite *suite, CutRunner *runner,
 
 gboolean
 cut_test_suite_run_test (CutTestSuite *suite, CutRunner *runner,
-                         const gchar *test_name)
+                         gchar *test_name)
 {
     GList *test_cases;
-    const gchar *test_names[] = {NULL, NULL};
+    gchar *test_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
 
@@ -436,12 +375,12 @@ cut_test_suite_run_test (CutTestSuite *suite, CutRunner *runner,
 
 gboolean
 cut_test_suite_run_test_in_test_case (CutTestSuite *suite,
-                                      CutRunner   *runner,
-                                      const gchar  *test_name,
-                                      const gchar  *test_case_name)
+                                      CutRunner    *runner,
+                                      gchar        *test_name,
+                                      gchar        *test_case_name)
 {
-    const gchar *test_names[] = {NULL, NULL};
-    const gchar *test_case_names[] = {NULL, NULL};
+    gchar *test_names[] = {NULL, NULL};
+    gchar *test_case_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
 
@@ -455,8 +394,8 @@ cut_test_suite_run_test_in_test_case (CutTestSuite *suite,
 gboolean
 cut_test_suite_run_with_filter (CutTestSuite *test_suite,
                                 CutRunner   *runner,
-                                const gchar **test_case_names,
-                                const gchar **test_names)
+                                gchar **test_case_names,
+                                gchar **test_names)
 {
     CutTestContainer *container;
     GList *filtered_test_cases = NULL;
@@ -467,10 +406,11 @@ cut_test_suite_run_with_filter (CutTestSuite *test_suite,
         filtered_test_cases =
             cut_test_container_filter_children(container, test_case_names);
     } else {
-        const gchar *default_test_case_names[] = {"/^test_/", NULL};
+        CutTestContainer *container;
+
+        container = CUT_TEST_CONTAINER(test_suite);
         filtered_test_cases =
-            cut_test_container_filter_children(container,
-                                               default_test_case_names);
+            g_list_copy(cut_test_container_get_children(container));
     }
 
     if (!filtered_test_cases)
