@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -63,20 +61,20 @@ gboolean        cut_test_suite_run           (CutTestSuite *suite,
                                               CutRunner    *runner);
 gboolean        cut_test_suite_run_test_case (CutTestSuite *suite,
                                               CutRunner    *runner,
-                                              const gchar  *test_case_name);
+                                              gchar       *test_case_name);
 gboolean        cut_test_suite_run_test      (CutTestSuite *suite,
                                               CutRunner    *runner,
-                                              const gchar  *name);
+                                              gchar        *name);
 gboolean        cut_test_suite_run_test_in_test_case
                                              (CutTestSuite *suite,
                                               CutRunner    *runner,
-                                              const gchar  *name,
-                                              const gchar  *test_case_name);
+                                              gchar        *name,
+                                              gchar       *test_case_name);
 gboolean        cut_test_suite_run_with_filter
                                              (CutTestSuite *test_suite,
                                               CutRunner    *runner,
-                                              const gchar **test_case_names,
-                                              const gchar **test_names);
+                                              gchar       **test_case_names,
+                                              gchar       **test_names);
 
 G_END_DECLS
 
