@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -50,18 +48,22 @@ cut_utils_create_regex_pattern (const gchar *string)
 }
 
 gboolean
-cut_utils_compare_string_array (const gchar **strings1, const gchar **strings2)
+cut_utils_compare_string_array (gchar **strings1, gchar **strings2)
 {
     gint i, length;
 
-    length = g_strv_length((gchar **)strings1);
+    if (!strings1 && !strings2)
+        return TRUE;
 
-    if (length != g_strv_length((gchar **)strings2))
+    if (!strings1 || !strings2)
+        return FALSE;
+
+    length = g_strv_length(strings1);
+
+    if (length != g_strv_length(strings2))
         return FALSE;
 
     for (i = 0; i < length; i++) {
-        if (!strings1[i] || !strings2[i])
-            return FALSE;
         if (strcmp(strings1[i], strings2[i]))
             return FALSE;
     }
@@ -69,6 +71,29 @@ cut_utils_compare_string_array (const gchar **strings1, const gchar **strings2)
     return TRUE;
 }
 
+gchar *
+cut_utils_inspect_string_array (gchar **strings)
+{
+    GString *inspected;
+    gchar **string, **next_string;
+
+    if (!strings)
+        return g_strdup("(null)");
+
+    inspected = g_string_new("[");
+    string = strings;
+    while (*string) {
+        g_string_append_printf(inspected, "\"%s\"", *string);
+        next_string = string + 1;
+        if (*next_string)
+            g_string_append(inspected, ", ");
+        string = next_string;
+    }
+    g_string_append(inspected, "]");
+
+    return g_string_free(inspected, FALSE);
+}
+
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
