@@ -2,28 +2,26 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef __CUTTER_H__
 #define __CUTTER_H__
 
-#include <cutter/cut-assertions.h>
 #include <cutter/cut-hidden-definitions.h>
+#include <cutter/cut-assertions.h>
 #include <cutter/cut-experimental.h>
 
 #ifdef __cplusplus
@@ -153,20 +151,24 @@ void setup(void);
 void teardown(void);
 
 /**
- * initialize:
+ * startup:
  *
- * If you define initialize() in your test program, cutter will
- * call your initialize() before each your test case is run.
+ * If you define startup() in your test program, cutter will
+ * call your startup() before each your test case is run.
+ *
+ * Since: 0.8
  */
-void initialize(void);
+void startup(void);
 
 /**
- * finalize:
+ * shutdown:
  *
- * If you define finalize() in your test program, cutter will
- * call your finalize() after each your test case is run.
+ * If you define shutdown() in your test program, cutter will
+ * call your shutdown() after each your test case is run.
+ *
+ * Since: 0.8
  */
-void finalize(void);
+void shutdown(void);
 
 
 #ifdef __cplusplus
