@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -30,6 +28,7 @@
 #include <gmodule.h>
 
 #include <cutter/cut-module-impl.h>
+#include <cutter/cut-listener.h>
 #include <cutter/cut-ui.h>
 #include <cutter/cut-runner.h>
 #include <cutter/cut-test-result.h>
@@ -64,7 +63,7 @@ typedef struct _CutUIConsoleClass CutUIConsoleClass;
 
 struct _CutUIConsole
 {
-    CutUI     object;
+    GObject       object;
     gchar        *name;
     gboolean      use_color;
     CutVerboseLevel verbose_level;
@@ -72,7 +71,7 @@ struct _CutUIConsole
 
 struct _CutUIConsoleClass
 {
-    CutUIClass parent_class;
+    GObjectClass parent_class;
 };
 
 enum
@@ -83,7 +82,7 @@ enum
 };
 
 static GType cut_type_ui_console = 0;
-static CutUIClass *parent_class;
+static GObjectClass *parent_class;
 
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
@@ -95,30 +94,27 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
-static void attach_to_runner   (CutListener *listener,
-                                CutRunner   *runner);
-static void detach_from_runner (CutListener *listener,
-                                CutRunner   *runner);
+static void     attach_to_runner   (CutListener *listener,
+                                    CutRunner   *runner);
+static void     detach_from_runner (CutListener *listener,
+                                    CutRunner   *runner);
+static gboolean run                (CutUI       *ui,
+                                    CutRunner   *runner);
 
 static void
-class_init (CutUIClass *klass)
+class_init (CutUIConsoleClass *klass)
 {
     GObjectClass *gobject_class;
-    CutListenerClass *listener_class;
     GParamSpec *spec;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
-    listener_class = CUT_LISTENER_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    listener_class->attach_to_runner   = attach_to_runner;
-    listener_class->detach_from_runner = detach_from_runner;
-
     spec = g_param_spec_boolean("use-color",
                                 "Use color",
                                 "Whether use color",
@@ -142,6 +138,19 @@ init (CutUIConsole *console)
     console->verbose_level = CUT_VERBOSE_LEVEL_NORMAL;
 }
 
+static void
+listener_init (CutListenerClass *listener)
+{
+    listener->attach_to_runner   = attach_to_runner;
+    listener->detach_from_runner = detach_from_runner;
+}
+
+static void
+ui_init (CutUIClass *ui)
+{
+    ui->run = run;
+}
+
 static void
 register_type (GTypeModule *type_module)
 {
@@ -158,10 +167,34 @@ register_type (GTypeModule *type_module)
             (GInstanceInitFunc) init,
         };
 
+	static const GInterfaceInfo ui_info =
+	    {
+            (GInterfaceInitFunc) ui_init,
+            NULL,
+            NULL
+        };
+
+	static const GInterfaceInfo listener_info =
+	    {
+            (GInterfaceInitFunc) listener_init,
+            NULL,
+            NULL
+        };
+
     cut_type_ui_console = g_type_module_register_type(type_module,
-                                                          CUT_TYPE_UI,
-                                                          "CutUIConsole",
-                                                          &info, 0);
+                                                      G_TYPE_OBJECT,
+                                                      "CutUIConsole",
+                                                      &info, 0);
+
+    g_type_module_add_interface(type_module,
+                                cut_type_ui_console,
+                                CUT_TYPE_UI,
+                                &ui_info);
+
+    g_type_module_add_interface(type_module,
+                                cut_type_ui_console,
+                                CUT_TYPE_LISTENER,
+                                &listener_info);
 }
 
 G_MODULE_EXPORT GList *
@@ -189,12 +222,6 @@ CUT_MODULE_IMPL_INSTANTIATE (const gchar *first_property, va_list var_args)
     return g_object_new_valist(CUT_TYPE_UI_CONSOLE, first_property, var_args);
 }
 
-G_MODULE_EXPORT gchar *
-CUT_MODULE_IMPL_GET_LOG_DOMAIN (void)
-{
-    return g_strdup(G_LOG_DOMAIN);
-}
-
 static void
 dispose (GObject *object)
 {
@@ -252,18 +279,21 @@ status_to_name(CutTestResultStatus status)
       case CUT_TEST_RESULT_SUCCESS:
         name = "Success";
         break;
+      case CUT_TEST_RESULT_NOTIFICATION:
+        name = "Notification";
+        break;
+      case CUT_TEST_RESULT_OMISSION:
+        name = "Omission";
+        break;
+      case CUT_TEST_RESULT_PENDING:
+        name = "Pending";
+        break;
       case CUT_TEST_RESULT_FAILURE:
         name = "Failure";
         break;
       case CUT_TEST_RESULT_ERROR:
         name = "Error";
         break;
-      case CUT_TEST_RESULT_PENDING:
-        name = "Pending";
-        break;
-      case CUT_TEST_RESULT_NOTIFICATION:
-        name = "Notification";
-        break;
       default:
         name = "MUST NOT HAPPEN!!!";
         break;
@@ -281,18 +311,21 @@ status_to_color(CutTestResultStatus status)
       case CUT_TEST_RESULT_SUCCESS:
         color = GREEN_COLOR;
         break;
+      case CUT_TEST_RESULT_NOTIFICATION:
+        color = CYAN_COLOR;
+        break;
+      case CUT_TEST_RESULT_OMISSION:
+        color = BLUE_COLOR;
+        break;
+      case CUT_TEST_RESULT_PENDING:
+        color = MAGENTA_COLOR;
+        break;
       case CUT_TEST_RESULT_FAILURE:
         color = RED_COLOR;
         break;
       case CUT_TEST_RESULT_ERROR:
         color = YELLOW_COLOR;
         break;
-      case CUT_TEST_RESULT_PENDING:
-        color = MAGENTA_COLOR;
-        break;
-      case CUT_TEST_RESULT_NOTIFICATION:
-        color = CYAN_COLOR;
-        break;
       default:
         color = "";
         break;
@@ -396,6 +429,45 @@ cb_success_test (CutRunner      *runner,
     fflush(stdout);
 }
 
+static void
+cb_notification_test (CutRunner      *runner,
+                      CutTest        *test,
+                      CutTestContext *test_context,
+                      CutTestResult  *result,
+                      CutUIConsole   *console)
+{
+    if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
+        return;
+    print_for_status(console, CUT_TEST_RESULT_NOTIFICATION, "N");
+    fflush(stdout);
+}
+
+static void
+cb_omission_test (CutRunner      *runner,
+                  CutTest        *test,
+                  CutTestContext *test_context,
+                  CutTestResult  *result,
+                  CutUIConsole   *console)
+{
+    if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
+        return;
+    print_for_status(console, CUT_TEST_RESULT_OMISSION, "O");
+    fflush(stdout);
+}
+
+static void
+cb_pending_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *test_context,
+                 CutTestResult  *result,
+                 CutUIConsole   *console)
+{
+    if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
+        return;
+    print_for_status(console, CUT_TEST_RESULT_PENDING, "P");
+    fflush(stdout);
+}
+
 static void
 cb_failure_test (CutRunner      *runner,
                  CutTest        *test,
@@ -422,32 +494,6 @@ cb_error_test (CutRunner      *runner,
     fflush(stdout);
 }
 
-static void
-cb_pending_test (CutRunner      *runner,
-                 CutTest        *test,
-                 CutTestContext *test_context,
-                 CutTestResult  *result,
-                 CutUIConsole   *console)
-{
-    if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
-        return;
-    print_for_status(console, CUT_TEST_RESULT_PENDING, "P");
-    fflush(stdout);
-}
-
-static void
-cb_notification_test (CutRunner      *runner,
-                      CutTest        *test,
-                      CutTestContext *test_context,
-                      CutTestResult  *result,
-                      CutUIConsole   *console)
-{
-    if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
-        return;
-    print_for_status(console, CUT_TEST_RESULT_NOTIFICATION, "N");
-    fflush(stdout);
-}
-
 static void
 cb_complete_test (CutRunner *runner, CutTest *test,
                   CutTestContext *test_context, CutUIConsole *console)
@@ -499,9 +545,6 @@ print_results (CutUIConsole *console, CutRunner *runner)
 {
     gint i;
     const GList *node;
-    CutUI *ui;
-
-    ui = CUT_UI(console);
 
     i = 1;
     for (node = cut_runner_get_results(runner);
@@ -553,16 +596,18 @@ static void
 print_summary (CutUIConsole *console, CutRunner *runner,
                gboolean crashed)
 {
-    guint n_tests, n_assertions, n_failures, n_errors;
-    guint n_pendings, n_notifications;
+    guint n_tests, n_assertions, n_successes, n_failures, n_errors;
+    guint n_pendings, n_notifications, n_omissions;
     const gchar *color;
 
     n_tests = cut_runner_get_n_tests(runner);
     n_assertions = cut_runner_get_n_assertions(runner);
+    n_successes = cut_runner_get_n_successes(runner);
     n_failures = cut_runner_get_n_failures(runner);
     n_errors = cut_runner_get_n_errors(runner);
     n_pendings = cut_runner_get_n_pendings(runner);
     n_notifications = cut_runner_get_n_notifications(runner);
+    n_omissions = cut_runner_get_n_omissions(runner);
 
     if (crashed) {
         color = CRASH_COLOR;
@@ -574,6 +619,8 @@ print_summary (CutUIConsole *console, CutRunner *runner,
             status = CUT_TEST_RESULT_FAILURE;
         } else if (n_pendings > 0) {
             status = CUT_TEST_RESULT_PENDING;
+        } else if (n_omissions > 0) {
+            status = CUT_TEST_RESULT_OMISSION;
         } else if (n_notifications > 0) {
             status = CUT_TEST_RESULT_NOTIFICATION;
         } else {
@@ -583,9 +630,14 @@ print_summary (CutUIConsole *console, CutRunner *runner,
     }
     print_with_color(console, color,
                      "%d test(s), %d assertion(s), %d failure(s), "
-                     "%d error(s), %d pending(s), %d notification(s)",
+                     "%d error(s), %d pending(s), %d omission(s), "
+                     "%d notification(s)",
                      n_tests, n_assertions, n_failures, n_errors,
-                     n_pendings, n_notifications);
+                     n_pendings, n_omissions, n_notifications);
+    g_print("\n");
+    print_with_color(console, color,
+                     "%g%% passed",
+                     100.0 * ((gdouble)n_successes / (gdouble)n_tests));
     g_print("\n");
 }
 
@@ -643,10 +695,11 @@ connect_to_runner (CutUIConsole *console, CutRunner *runner)
     CONNECT(start_test);
 
     CONNECT(success_test);
+    CONNECT(notification_test);
+    CONNECT(omission_test);
+    CONNECT(pending_test);
     CONNECT(failure_test);
     CONNECT(error_test);
-    CONNECT(pending_test);
-    CONNECT(notification_test);
 
     CONNECT(complete_test);
     CONNECT(complete_test_case);
@@ -670,10 +723,11 @@ disconnect_from_runner (CutUIConsole *console, CutRunner *runner)
     DISCONNECT(start_test);
 
     DISCONNECT(success_test);
+    DISCONNECT(notification_test);
+    DISCONNECT(omission_test);
+    DISCONNECT(pending_test);
     DISCONNECT(failure_test);
     DISCONNECT(error_test);
-    DISCONNECT(pending_test);
-    DISCONNECT(notification_test);
 
     DISCONNECT(complete_test);
     DISCONNECT(complete_test_case);
@@ -698,6 +752,12 @@ detach_from_runner (CutListener *listener,
     disconnect_from_runner(CUT_UI_CONSOLE(listener), runner);
 }
 
+static gboolean
+run (CutUI *ui, CutRunner *runner)
+{
+    return cut_runner_run(runner);
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
