@@ -14,12 +14,13 @@ if test x"$CUTTER_DEBUG" = x"yes"; then
     CUTTER="$BASE_DIR/../libtool --mode=execute gdb --args $CUTTER"
 fi
 
+export CUTTER
 export CUT_UI_MODULE_DIR=$BASE_DIR/../cutter/module/ui/.libs
 export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/ui/.libs
 export CUT_REPORT_MODULE_DIR=$BASE_DIR/../cutter/module/report/.libs
 export CUT_REPORT_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/report/.libs
 
-CUTTER_ARGS="--multi-thread -s $BASE_DIR"
+CUTTER_ARGS="-s $BASE_DIR"
 if test x"$USE_GTK" = x"yes"; then
     CUTTER_ARGS="-u gtk $CUTTER_ARGS"
 fi
