@@ -23,6 +23,8 @@ void test_error_equal_string (void);
 void test_error_equal_string_with_null (void);
 void test_assert_equal_function (void);
 void test_failure_from_nested_function (void);
+void test_assert_errno (void);
+void test_omit (void);
 
 static gboolean need_cleanup;
 static gboolean compare_function_is_called;
@@ -157,7 +159,7 @@ void
 test_equal_double (void)
 {
     cut_assert_equal_double(1.0, 0.1, 1.0);
-    cut_assert_equal_double(1.0, 0.01, 1.01);
+    cut_assert_equal_double(1.01, 0.01, 1.01);
 }
 
 void
@@ -175,8 +177,8 @@ test_operator (void)
 void
 test_equal_string_array (void)
 {
-    const gchar *strings1[] = {"a", "b", "c", NULL};
-    const gchar *strings2[] = {"a", "b", "c", NULL};
+    gchar *strings1[] = {"a", "b", "c", NULL};
+    gchar *strings2[] = {"a", "b", "c", NULL};
 
     cut_assert_equal_string_array(strings1, strings2);
 }
@@ -220,7 +222,7 @@ test_error (void)
     cut_assert(test, "Creating a new CutTest object failed");
 
     cut_assert(!run(test));
-    cut_assert_test_result_summary(runner, 1, 0, 0, 1, 0, 0);
+    cut_assert_test_result_summary(runner, 1, 0, 0, 1, 0, 0, 0);
     cut_assert_test_result(runner, 0, CUT_TEST_RESULT_ERROR, "dummy-error-test",
                            "This test should error", NULL,
                            "dummy_error_test_function");
@@ -335,7 +337,12 @@ test_assert_message_with_format_string (void)
                "since \"failure\" signal was not emmitted.");
     cut_assert_equal_int(CUT_TEST_RESULT_FAILURE,
                          cut_test_result_get_status(test_result));
-    cut_assert_equal_string("<\"%s\" == \"%d\">\nexpected: <%s>\n but was: <%d>",
+    cut_assert_equal_string("<\"%s\" == \"%d\">\n"
+                            "expected: <%s>\n"
+                            " but was: <%d>\n"
+                            "diff:\n"
+                            "- %s\n"
+                            "+ %d",
                             cut_test_result_get_system_message(test_result));
     cut_assert_equal_string("expected and actual have format string",
                             cut_test_result_get_user_message(test_result));
@@ -408,7 +415,7 @@ test_null_string (void)
 
     test = cut_test_new("assert-null-string", null_string_assertions);
     cut_assert(!run(test));
-    cut_assert_test_result_summary(runner, 1, 1, 1, 0, 0, 0);
+    cut_assert_test_result_summary(runner, 1, 1, 1, 0, 0, 0, 0);
 }
 
 static void
@@ -428,10 +435,48 @@ test_equal_string_with_free (void)
     test = cut_test_new("assert-string-equal-string-with-free",
                         equal_string_with_free_assertions);
     cut_assert(!run(test));
-    cut_assert_test_result_summary(runner, 1, 3, 1, 0, 0, 0);
+    cut_assert_test_result_summary(runner, 1, 3, 1, 0, 0, 0, 0);
 }
 
+static void
+assert_errno_for_eacces (void)
+{
+    errno = 0;
+    cut_assert_errno("Passed");
+
+    errno = EACCES;
+    cut_assert_errno("Failed");
+}
+
+void
+test_assert_errno (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("assert-errno-for-eacces", assert_errno_for_eacces);
+    cut_assert(!run(test));
+    cut_assert_test_result_summary(runner, 1, 1, 1, 0, 0, 0, 0);
+}
+
+static void
+omit_test (void)
+{
+    cut_assert_equal_int(1, 1);
+    cut_omit("Omit the following tests");
+    cut_assert_equal_int(2, 2);
+}
+
+void
+test_omit (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("omit-test", omit_test);
+    cut_assert(run(test));
+    cut_assert_test_result_summary(runner, 1, 1, 0, 0, 0, 0, 1);
+}
+
+
 /*
 vi:nowrap:ai:expandtab:sw=4
 */
-
