@@ -13,6 +13,8 @@ void test_pass_assertion_signal(void);
 void test_failure_signal(void);
 void test_pending_signal(void);
 void test_notification_signal(void);
+void test_omission_signal(void);
+void test_test_function (void);
 
 static CutRunner *runner;
 static CutTest *test_object;
@@ -25,6 +27,7 @@ static gint n_error_signal = 0;
 static gint n_pending_signal = 0;
 static gint n_pass_assertion_signal = 0;
 static gint n_notification_signal = 0;
+static gint n_omission_signal = 0;
 
 static void
 dummy_test_function (void)
@@ -59,6 +62,12 @@ dummy_error_function (void)
     cut_error("This test should error");
 }
 
+static void
+dummy_omission_function (void)
+{
+    cut_omit("This test should be omitted");
+}
+
 void
 setup (void)
 {
@@ -71,6 +80,7 @@ setup (void)
     n_pending_signal = 0;
     n_notification_signal = 0;
     n_pass_assertion_signal = 0;
+    n_omission_signal = 0;
 
     runner = cut_runner_new();
 
@@ -126,6 +136,12 @@ cb_pass_assertion_signal (CutTest *test, gpointer data)
     n_pass_assertion_signal++;
 }
 
+static void
+cb_omission_signal (CutTest *test, gpointer data)
+{
+    n_omission_signal++;
+}
+
 static gboolean
 run (CutTest *test)
 {
@@ -144,11 +160,26 @@ run (CutTest *test)
     return success;
 }
 
+void 
+test_test_function (void)
+{
+    CutTestFunction test_function;
+
+    g_object_get(test_object,
+                 "test-function", &test_function,
+                 NULL);
+    cut_assert_equal_int(GPOINTER_TO_UINT(dummy_test_function),
+                         GPOINTER_TO_UINT(test_function));
+}
+
 void
 test_get_name (void)
 {
     cut_assert_equal_string("dummy-test",
                             cut_test_get_name(test_object));
+    cut_test_set_name(test_object, "new-name");
+    cut_assert_equal_string("new-name",
+                            cut_test_get_name(test_object));
 }
 
 void
@@ -256,6 +287,23 @@ test_notification_signal (void)
     g_object_unref(test);
 }
 
+void
+test_omission_signal (void)
+{
+    CutTest *test;
+
+    test = cut_test_new("dummy-omission-test", dummy_omission_function);
+    cut_assert(test);
+
+    g_signal_connect(test, "omission", G_CALLBACK(cb_omission_signal), NULL);
+    cut_assert(run(test));
+    g_signal_handlers_disconnect_by_func(test,
+                                         G_CALLBACK(cb_omission_signal),
+                                         NULL);
+    cut_assert_equal_int(1, n_omission_signal);
+    g_object_unref(test);
+}
+
 void
 test_pass_assertion_signal (void)
 {
@@ -268,5 +316,5 @@ test_pass_assertion_signal (void)
 }
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
